@@ -8,8 +8,7 @@ import os
 import uritools
 
 from mopidy.audio.scan import Scanner
-from mopidy.local.translator import local_track_uri_to_path
-from mopidy.utils.path import get_or_create_file, path_to_uri
+from mopidy.utils.path import get_or_create_file, uri_to_path
 
 from . import Extension
 
@@ -18,38 +17,35 @@ logger = logging.getLogger(__name__)
 
 class ImageDirectory(object):
 
-    root = None
-
     def __init__(self, config):
         ext_config = config[Extension.ext_name]
+        if ext_config['image_dir']:
+            self.root = ext_config['image_dir']
+        else:
+            self.root = Extension.get_data_dir(config, b'images')
         self._base_uri = ext_config['image_base_uri']
-        self._media_dir = config['local']['media_dir']
         self._patterns = map(str, ext_config['album_art_files'])
-        self._scanner = Scanner(config['local']['scan_timeout'])
-        self.root = Extension.make_data_dir(config, ext_config['image_dir'])
-
-    def add(self, track):
-        if not track.album:
-            return track  # cannot add images w/o album
-        path = local_track_uri_to_path(track.uri, self._media_dir)
-        data = self._scanner.scan(path_to_uri(path))
+        self._scanner = None
 
+    def scan(self, uri):
+        if not self._scanner:
+            self._scanner = Scanner()
+        data = self._scanner.scan(uri)
+        logger.debug('Scanning for images: %r', data)
         images = []
         for image in data['tags'].get('image', []):
             try:
-                images.append(self._image(None, image.data))
+                images.append(self._get_or_create_image(None, image.data))
             except Exception as e:
-                logger.warn('Cannot extract image from %s: %s', track.uri, e)
-
-        dirname = os.path.dirname(path)
+                logger.warn('Cannot extract image from %s: %s', uri, e)
+        dirname = os.path.dirname(uri_to_path(uri))
         for pattern in self._patterns:
             for path in glob.glob(os.path.join(dirname, pattern)):
                 try:
-                    images.append(self._image(path))
+                    images.append(self._get_or_create_image(path))
                 except Exception as e:
                     logger.warn('Cannot read album art from %s: %s', path, e)
-
-        return track.copy(album=track.album.copy(images=images))
+        return images
 
     def cleanup(self, uris):
         if not os.path.isdir(self.root):
@@ -71,9 +67,6 @@ class ImageDirectory(object):
             for name in files:
                 os.remove(os.path.join(root, name))
 
-    def geturi(self, filename):
-        return uritools.urijoin(self._base_uri, filename)
-
     def uris(self):
         if not os.path.isdir(self.root):
             raise StopIteration
@@ -81,7 +74,10 @@ class ImageDirectory(object):
             for name in files:
                 yield self.geturi(name)
 
-    def _image(self, path, data=None):
+    def geturi(self, filename):
+        return uritools.urijoin(self._base_uri, filename)
+
+    def _get_or_create_image(self, path, data=None):
         what = imghdr.what(path, data)
         if not what:
             raise ValueError('Unknown image type')
