@@ -16,9 +16,8 @@ class ExtensionTest(unittest.TestCase):
     def test_get_config_schema(self):
         ext = Extension()
         schema = ext.get_config_schema()
+        self.assertIn('directories', schema)
         self.assertIn('encodings', schema)
-        self.assertIn('hash', schema)
+        self.assertIn('timeout', schema)
         self.assertIn('use_album_mbid_uri', schema)
         self.assertIn('use_artist_mbid_uri', schema)
-        self.assertIn('foreign_keys', schema)
-        self.assertIn('timeout', schema)
